@@ -419,12 +419,12 @@ def get_template_type(template_dir):
 
 
 def get_last_version(template_name, api_address, headers):
-    api_url = api_address + "/public/templates/" + template_name + "/versions/"
+    api_url = api_address + "/public/templates/" + template_name + "/versions"
     try:
         cookies = {}
         authorized = is_authorized(api_address, headers)
         if authorized:
-            api_url = api_address + "/templates/" + template_name + "/versions/"
+            api_url = api_address + "/templates/" + template_name + "/versions"
             headers, cookies = authorization(headers)
         response = requests.get(api_url, headers=headers, cookies=cookies)
         response.raise_for_status()
@@ -585,7 +585,7 @@ def add_template_to_group(args, api_address, headers):
     headers, cookies = authorization(headers)
     group_name = args.group_name if args.group_name else input("Template group name: ")
     template_name = args.template_name if args.template_name else input("Template name: ")
-    api_url = api_address + "/templates/" + template_name + "/groups?group_name=" + group_name
+    api_url = api_address + "/templates/" + template_name + "/groups?groupName=" + group_name
 
     try:
         response = requests.post(api_url, headers=headers, cookies=cookies)
@@ -600,7 +600,7 @@ def remove_template_from_group(args, api_address, headers):
     headers, cookies = authorization(headers)
     group_name = args.group_name if args.group_name else input("Template group name: ")
     template_name = args.template_name if args.template_name else input("Template name: ")
-    api_url = api_address + "/templates/" + template_name + "/groups?group_name=" + group_name
+    api_url = api_address + "/templates/" + template_name + "/groups?groupName=" + group_name
     print(api_url)
     try:
         response = requests.delete(api_url, headers=headers, cookies=cookies)
@@ -745,7 +745,7 @@ def add_user_to_group(args, api_address, headers):
     headers, cookies = authorization(headers)
     username = args.username if args.username else input("Username of the user to add: ")
     group_name = args.group_name if args.group_name else input("Name of the user group: ")
-    api_url = api_address + "/users/" + username + "/groups?group_name=" + group_name
+    api_url = api_address + "/users/" + username + "/groups?groupName=" + group_name
 
     try:
         response = requests.post(api_url, headers=headers, cookies=cookies)
@@ -775,7 +775,7 @@ def remove_user_from_group(args, api_address, headers):
     headers, cookies = authorization(headers)
     username = args.username if args.username else input("Username of the user to remove: ")
     group_name = args.group_name if args.group_name else input("Name of the user group: ")
-    api_url = api_address + "/users/" + username + "/groups?group_name=" + group_name
+    api_url = api_address + "/users/" + username + "/groups?groupName=" + group_name
 
     try:
         response = requests.delete(api_url, headers=headers, cookies=cookies)
@@ -1056,8 +1056,13 @@ def login_keycloak_identity_provider_user(api_address, keycloak_address, identit
         exit(1)
 
 
-def logout_user():
+def logout_user(api_address, headers):
+    headers, cookies = authorization(headers)
+    api_url = api_address + "/api/user/current/logout"
     try:
+        response = requests.get(api_url, headers=headers)
+        response.raise_for_status()
+
         if os.path.exists(env_path + '/.username'):
             os.remove(env_path + '/.username')
         # Logout KeyCloak user
@@ -1476,7 +1481,7 @@ def main():
         print(f"{cli_style['green']}User '{username}' logged in.{cli_style['end']}")
 
     if args.command == "logout":
-        logout_user()
+        logout_user(api_address, headers)
 
     if args.command == "user":
         if args.users == "template-groups":
